# Data Algorithms

!!! tip inline end "Data Algorithms"
    WIP: These classes are currently actively being developed and are subject to change in both API and functionality over time. They provide a set of data algorithms for various types of data storage. We currently have subdirectorys for:
    
- **[DataFrames](dataframes/overview.md):** A set of algorithms that consume/return a Panda dataFrame.
- **[Graphs](graphs/overview.md):** Algorithms for node/edge graphs, specifically focused on NetworkX graphs.
- **[Spark](spark/overview.md):** A set of algorithms that consume/return a Spark dataFrame.
- **[SQL](sql/overview.md):** SQL queries that provide a wide range of functionality:

    - Outliers
    - Descriptive Stats
    - Correlations
    - and More

**Welcome to the Workbench Data Algorithms**

Docs TBD

## Questions?
<img align="right" src="../../images/scp.png" width="180">

The SuperCowPowers team is happy to answer any questions you may have about AWS and Workbench. Please contact us at [workbench@supercowpowers.com](mailto:workbench@supercowpowers.com) or on chat us up on [Discord](https://discord.gg/WHAJuz8sw8) 


